bayespy.inference.vmp.nodes.expfamily.ExponentialFamily.dims
============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.expfamily

.. autoattribute:: ExponentialFamily.dims